@@ -47,6 +47,9 @@ plot_tb_burden_overview <- function(df = NULL, dict = NULL,
                                     save = TRUE,
                                     burden_save_name = "TB_burden",
                                     dict_save_name = "TB_data_dict",
+                                    viridis_palette = "viridis",
+                                    viridis_direction = -1,
+                                    viridis_end = 0.9,
                                     verbose = TRUE, 
                                     ...) {
  
@@ -72,10 +75,12 @@ plot_tb_burden_overview <- function(df = NULL, dict = NULL,
     geom_point(alpha = 0.6, size = 1.5)
   
   plot <- plot +
-    scale_colour_viridis(end = 0.9, direction = -1,
-                         discrete = FALSE, trans = trans) +
+    scale_colour_viridis(end = viridis_end, direction = viridis_direction,
+                         discrete = FALSE, trans = trans,
+                         option = viridis_palette) +
     theme_minimal() +
-    labs(x = "Country", y = df_prep$metric_label) + 
+    labs(x = "Country", y = df_prep$metric_label,
+         caption = "Source: World Health Organisation") + 
     coord_flip()
   
   if (annual_change) {
